@@ -6,25 +6,29 @@ from operator import mul
 
 from PyQt4.QtCore import Qt, QSize
 from PyQt4.QtGui import (
-    QGraphicsRectItem, QGraphicsView, QColor, QGraphicsScene, QPainter, QPen,
-    QGraphicsTextItem, QBrush, QGraphicsLineItem)
+    QColor, QGraphicsScene, QPainter, QPen,
+    QGraphicsLineItem)
+
 from Orange.data import Table, filter
 from Orange.data.sql.table import SqlTable, LARGE_TABLE, DEFAULT_SAMPLE_TIME
+from Orange.preprocess import Discretize
+from Orange.preprocess.discretize import EqualFreq
 from Orange.statistics.distribution import get_distribution
 from Orange.widgets import gui
 from Orange.widgets.settings import (
     Setting, DomainContextHandler, ContextSetting)
-from Orange.widgets.utils import getHtmlCompatibleString
+from Orange.widgets.utils import to_html
 from Orange.widgets.utils.scaling import get_variable_values_sorted
-from Orange.widgets.widget import OWWidget, Default
-from Orange.preprocess import Discretize
-from Orange.preprocess.discretize import EqualFreq
+from Orange.widgets.visualize.utils import (
+    CanvasText, CanvasRectangle, ViewWithPress)
+from Orange.widgets.widget import OWWidget, Default, Msg
 
 
 class OWMosaicDisplay(OWWidget):
     name = "Mosaic Display"
     description = "Display data in a mosaic plot."
     icon = "icons/MosaicDisplay.svg"
+    priority = 320
 
     inputs = [("Data", Table, "set_data", Default),
               ("Data Subset", Table, "set_subset_data")]
@@ -55,6 +59,12 @@ class OWMosaicDisplay(OWWidget):
 
     graph_name = "canvas"
 
+    class Warning(OWWidget.Warning):
+        incompatible_subset = Msg("Data subset is incompatible with Data")
+        no_valid_data = Msg("No valid data")
+        no_cont_selection_sql = \
+            Msg("Selection of continuous variables on SQL is not supported")
+
     def __init__(self):
         super().__init__()
 
@@ -141,14 +151,9 @@ class OWMosaicDisplay(OWWidget):
         self.closeContext()
         self.data = data
         self.init_combos(self.data)
-        self.information([0, 1, 2])
         if not self.data:
             self.discrete_data = None
             return
-        """ TODO: check
-        if data.has_missing_class():
-            self.information(1, "Examples with missing classes were removed.")
-        """
         if any(attr.is_continuous for attr in data.domain):
             self.discrete_data = Discretize(method=EqualFreq(n=4))(data)
         else:
@@ -171,19 +176,15 @@ class OWMosaicDisplay(OWWidget):
             self.unprocessed_subset_data = None
 
     def set_subset_data(self, data):
+        self.Warning.incompatible_subset.clear()
         if self.data is None:
             self.unprocessed_subset_data = data
-            self.warning(10)
             return
         try:
             self.subset_data = data.from_table(self.data.domain, data)
-            self.warning(10)
         except:
             self.subset_data = None
-            self.warning(
-                10,
-                "'Data' and 'Data Subset' are incompatible" if data is not None
-                else "")
+            self.Warning.incompatible_subset(shown=data is not None)
 
     # this is called by widget after setData and setSubsetData are called.
     # this way the graph is updated only once
@@ -221,12 +222,10 @@ class OWMosaicDisplay(OWWidget):
             self.send("Selected Data", None)
             return
         filters = []
-        self.warning(6)
+        self.Warning.no_cont_selection_sql.clear()
         if self.discrete_data is not self.data:
             if isinstance(self.data, SqlTable):
-                self.warning(
-                    6,
-                    "Selection of continuous variables on SQL is not supported")
+                self.Warning.no_cont_selection_sql()
         for i in self.selection:
             cols, vals, area = self.areas[i]
             filters.append(
@@ -306,7 +305,7 @@ class OWMosaicDisplay(OWWidget):
                 start = i * edge + whole * float(sum(counts[:i]) / total)
                 end = i * edge + whole * float(sum(counts[:i + 1]) / total)
                 val = values[i]
-                htmlval = getHtmlCompatibleString(val)
+                htmlval = to_html(val)
                 if attr_vals != "":
                     newattrvals = attr_vals + "-" + val
                 else:
@@ -639,10 +638,10 @@ class OWMosaicDisplay(OWWidget):
         # TODO: check this
         # data = Preprocessor_dropMissing(data)
         if len(data) == 0:
-            self.warning(5, "No valid data for current attributes.")
+            self.Warning.no_valid_data()
             return
         else:
-            self.warning(5)
+            self.Warning.no_valid_data.clear()
 
         if self.interior_coloring == self.PEARSON:
             apriori_dists = [get_distribution(data, attr) for attr in attr_list]
@@ -740,97 +739,6 @@ def get_conditional_distribution(data, attrs):
     return cond_dist, dist
 
 
-class CanvasText(QGraphicsTextItem):
-    def __init__(self, canvas, text="", x=0, y=0,
-                 alignment=Qt.AlignLeft | Qt.AlignTop, bold=0, font=None, z=0,
-                 html_text=None, tooltip=None, show=1, vertical=False):
-        QGraphicsTextItem.__init__(self, text, None)
-
-        if font:
-            self.setFont(font)
-        if bold:
-            font = self.font()
-            font.setBold(bold)
-            self.setFont(font)
-        if html_text:
-            self.setHtml(html_text)
-
-        self.alignment = alignment
-        self.vertical = vertical
-        if vertical:
-            self.setRotation(-90)
-
-        self.setPos(x, y)
-        self.x, self.y = x, y
-        self.setZValue(z)
-        if tooltip:
-            self.setToolTip(tooltip)
-        if show:
-            self.show()
-        else:
-            self.hide()
-
-        if canvas is not None:
-            canvas.addItem(self)
-
-    def setPos(self, x, y):
-        self.x, self.y = x, y
-        rect = QGraphicsTextItem.boundingRect(self)
-        if self.vertical:
-            h, w = rect.height(), rect.width()
-            rect.setWidth(h)
-            rect.setHeight(-w)
-        if int(self.alignment & Qt.AlignRight):
-            x -= rect.width()
-        elif int(self.alignment & Qt.AlignHCenter):
-            x -= rect.width() / 2.
-        if int(self.alignment & Qt.AlignBottom):
-            y -= rect.height()
-        elif int(self.alignment & Qt.AlignVCenter):
-            y -= rect.height() / 2.
-        QGraphicsTextItem.setPos(self, x, y)
-
-
-class CanvasRectangle(QGraphicsRectItem):
-    def __init__(self, canvas, x=0, y=0, width=0, height=0,
-                 pen_color=QColor(128, 128, 128), brush_color=None, pen_width=1,
-                 z=0, pen_style=Qt.SolidLine, pen=None, tooltip=None, show=1,
-                 onclick=None):
-        super().__init__(x, y, width, height, None)
-        self.onclick = onclick
-        if brush_color:
-            self.setBrush(QBrush(brush_color))
-        if pen:
-            self.setPen(pen)
-        else:
-            self.setPen(QPen(QBrush(pen_color), pen_width, pen_style))
-        self.setZValue(z)
-        if tooltip:
-            self.setToolTip(tooltip)
-        if show:
-            self.show()
-        else:
-            self.hide()
-
-        if canvas is not None:
-            canvas.addItem(self)
-
-    def mousePressEvent(self, ev):
-        if self.onclick:
-            self.onclick(self, ev)
-
-
-class ViewWithPress(QGraphicsView):
-    def __init__(self, *args, **kwargs):
-        self.handler = kwargs.pop("handler")
-        super().__init__(*args)
-
-    def mousePressEvent(self, ev):
-        super().mousePressEvent(ev)
-        if not ev.isAccepted():
-            self.handler()
-
-
 # test widget appearance
 if __name__ == "__main__":
     import sys
